## ------------------------------------------------------------------------
library(dplyr)
library(MASS)

## ------------------------------------------------------------------------
library(ggplot2)
library(scales)
library(psych)
library(car)
library(relaimpo)
survey <- read.delim("survey.csv",sep = ';')
dia <- dplyr::filter(survey, Establecimiento=='dia')
carrefour <- dplyr::filter(survey, Establecimiento=='carrefour')
mercadona <- dplyr::filter(survey, Establecimiento=='mercadona')

## ------------------------------------------------------------------------
formula(
  paste('Ph1.Satisfaccion ~',
  paste(colnames(dplyr::select(survey, starts_with('P'),-Ph1.Satisfaccion)),
        collapse = '+')))

## ------------------------------------------------------------------------
survey_fit_SG <- lm(formula(
  paste('Ph1.Satisfaccion ~',
  paste(colnames(dplyr::select(survey, starts_with('P'),-Ph1.Satisfaccion)),
        collapse = '+'))),
  data = survey)
summary(survey_fit_SG)

## ------------------------------------------------------------------------
survey_fit_SG_step <- MASS::stepAIC(survey_fit_SG, trace = 0)
summary(survey_fit_SG_step)

## ------------------------------------------------------------------------
print(car::vif(survey_fit_SG_step), digits = 2)

## ------------------------------------------------------------------------
car::durbinWatsonTest(survey_fit_SG_step)

## ------------------------------------------------------------------------
survey_fit_SG_step_relaimp <- data.frame(
  relaimp = relaimpo::calc.relimp(survey_fit_SG_step, rela = TRUE)$lmg)
survey_fit_SG_step_relaimp$variables <- rownames(survey_fit_SG_step_relaimp)
dplyr::arrange(survey_fit_SG_step_relaimp, desc(relaimp))

## ------------------------------------------------------------------------
ggplot(survey_fit_SG_step_relaimp, 
       aes(reorder(as.factor(variables), relaimp), relaimp)) +
  geom_bar(stat = 'identity', fill = 'blue') +
  scale_y_continuous(labels = scales::percent) +
  labs(title = 'Importancia relativa por variable',
       subtitle = 'Var. dep. Satisfaccion Global' , x = '', y = '') +
  coord_flip()

## ------------------------------------------------------------------------
survey_principal_rot <- psych::principal(
  dplyr::select(survey, starts_with('P'), -Ph1.Satisfaccion ),
  nfactors = 4, rotate = 'varimax', scores = TRUE, method = 'regression')
survey_principal_scores_rot <- data.frame(unclass(survey_principal_rot$scores))
colnames(survey_principal_scores_rot) <- 
  c('Actitud', 'Establecimiento', 'Esperas', 'Oferta')
survey_principal_scores_rot <- cbind(survey_principal_scores_rot,
                                     Ph1.Satisfaccion = survey$Ph1.Satisfaccion)
print(head(survey_principal_scores_rot), digits = 2)

## ------------------------------------------------------------------------
survey_fit_factor_SG <- lm(Ph1.Satisfaccion ~ 
                    Actitud + Establecimiento + Esperas + Oferta,
                    data = survey_principal_scores_rot)
summary(survey_fit_factor_SG)

## ------------------------------------------------------------------------
car::vif(survey_fit_factor_SG)
car::durbinWatsonTest(survey_fit_factor_SG)

## ------------------------------------------------------------------------
survey_fit_factor_SG_relaimp <- data.frame(
  relaimp = relaimpo::calc.relimp(survey_fit_factor_SG, rela = TRUE)$lmg)
survey_fit_factor_SG_relaimp$variables <- rownames(survey_fit_factor_SG_relaimp)
ggplot(survey_fit_factor_SG_relaimp, 
       aes(reorder(as.factor(variables), relaimp), relaimp)) +
  geom_bar(stat = 'identity', fill = 'blue') +
  scale_y_continuous(labels = scales::percent) +
  labs(title = 'Importancia relativa por factor',
       subtitle = 'Var. dep. Satisfaccion Global' , x = '', y = '') +
  coord_flip()

## ------------------------------------------------------------------------
survey_principal_rot <- psych::principal(
  dplyr::select(survey, starts_with('P')),
  nfactors = 4, rotate = 'varimax', scores = TRUE, method = 'regression')
survey_principal_scores_rot <- data.frame(unclass(survey_principal_rot$scores))
colnames(survey_principal_scores_rot) <- 
  c('Actitud', 'Establecimiento', 'Esperas', 'Oferta')
survey_principal_scores_rot <- cbind(survey_principal_scores_rot,
                                     dplyr::select(survey, starts_with('R')))

## ------------------------------------------------------------------------
formula_IM <- formula(
  paste('RC4.CompraMedia ~',
  paste(colnames(dplyr::select(survey_principal_scores_rot, -RC4.CompraMedia)),
        collapse='+')))
survey_fit_IM <- lm(formula_IM, data= survey_principal_scores_rot)
summary(survey_fit_IM)

## ------------------------------------------------------------------------
survey_fit_IM_relaimp <- data.frame(
  relaimp = relaimpo::calc.relimp(survey_fit_IM, rela = TRUE)$lmg)
survey_fit_IM_relaimp$variables <- rownames(survey_fit_IM_relaimp)
dplyr::arrange(survey_fit_IM_relaimp,desc(relaimp))

## -------------------------------------------------------------------------
ggplot(survey_fit_IM_relaimp, aes(reorder(as.factor(variables), relaimp), relaimp)) +
  geom_bar(stat = 'identity', fill = 'blue') +
  scale_y_continuous(labels = scales::percent) +
  labs(title = 'Importancia relativa por variable',
       subtitle = 'Var. dep. Importe medio compra' , x = '', y = '') +
  coord_flip()

